@@ -23,8 +23,8 @@ Description:
 CVS Information:
  
     $Source: /home/globdev/CVS/globus-packages/gatekeeper/source/globus_gatekeeper.c,v $
-    $Date: 2010/03/09 15:06:24 $
-    $Revision: 1.97.2.2 $
+    $Date: 2011/02/10 17:06:17 $
+    $Revision: 1.97.2.4 $
     $Author: bester $
 
  This source file has been modified by Brent Milne (BMilne@lbl.gov)
@@ -1270,6 +1270,7 @@ main(int xargc,
                 listener_fd = -1;
 
                 dup2(connection_fd, 0);
+                fcntl(connection_fd, F_SETFD, 1);
                 /* this should work, but not sure !? */
                 /* Reports say it is needed on some systems */
                 *stdin = *fdopen(0,"r"); /* reopen stdin  we need this since */
@@ -1384,7 +1385,7 @@ static void doit()
             peernum = "";
     }
 
-    fdout = fdopen(dup(0),"w"); /* establish an output stream */
+    fdout = fdopen(1,"w"); /* establish an output stream */
     setbuf(fdout,NULL);
 
     notice3(LOG_INFO, "Got connection %s at %s", peernum, timestamp());
@@ -2077,22 +2078,19 @@ static void doit()
         setenv("LOGIN",userid,1);
         setenv("HOME",pw->pw_dir,1);
         setenv("SHELL",pw->pw_shell,1);
-        /* 
-         * Could set path, and other variables as well 
-         * Unset many of the gssapi set env variables. 
-         * If not present won't hurt to unset. 
-         * Leave the X509_CERT_DIR of trusted certs
-         * for the user to use. 
-         */
-        unsetenv("GRIDMAP"); /* unset it */
-        unsetenv("GLOBUSCERTDIR"); /* unset it */
-        unsetenv("GLOBUSKEYDIR"); /* unset it */
-        unsetenv("X509_USER_KEY"); /* unset it */
-        unsetenv("X509_USER_CERT"); /* unset it */
-
-	/* SLANG - can't unset this, otherwise jobmanager won't know where to look. */
-	/* unsetenv("X509_USER_PROXY"); */ /* unset it  */
     }
+    /* 
+     * Could set path, and other variables as well 
+     * Unset many of the gssapi set env variables. 
+     * If not present won't hurt to unset. 
+     * Leave the X509_CERT_DIR of trusted certs
+     * for the user to use. 
+     */
+    unsetenv("GRIDMAP"); /* unset it */
+    unsetenv("GLOBUSCERTDIR"); /* unset it */
+    unsetenv("GLOBUSKEYDIR"); /* unset it */
+    unsetenv("X509_USER_KEY"); /* unset it */
+    unsetenv("X509_USER_CERT"); /* unset it */
 
     /* for tranition, if gatekeeper has the path, set it
      * for the grid_services to use 
